@@ -2,7 +2,7 @@
   op <- options()
   op.tabula <- list(
     tabula.progress = TRUE,
-    tabula.verbose = TRUE
+    tabula.verbose = FALSE
   )
   toset <- !(names(op.tabula) %in% names(op))
   if(any(toset)) options(op.tabula[toset])
